/*
Pluck: an open source trivia game for Android

Copyright (C) 2021 Joguitos do luca0N!

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see <https://www.gnu.org/licenses/>.

This game is a fork of LibreTrivia, and its source code is available at
<https://github.com/tryton-vanmeer/LibreTrivia>.

Contact us at <joguitos+pluck@luca0n.com>.
*/

package com.luca0n.joguitos.pluck.trivia;

import java.util.HashMap;
import java.util.Map;

import com.luca0n.joguitos.pluck.PluckApplication;
import com.luca0n.joguitos.pluck.R;

public enum TriviaSource {
    SERVER("server", R.string.source_server),
    FILE("file", R.string.source_file);

    // Name of source
    private final String name;
    // Display name of the source
    private final int displayName;

    private static final Map<String, TriviaSource> lookup = new HashMap<>();

    static {
        for (TriviaSource source : TriviaSource.values()) {
            lookup.put(source.getName(), source);
        }
    }

    TriviaSource(String name, int displayName) {
        this.name = name;
        this.displayName = displayName;
    }

    public String getName() {
        return this.name;
    }

    public static TriviaSource get(String name) {
        return lookup.get(name);
    }

    @Override
    public String toString() {
        return PluckApplication.getAppContext().getResources().getString(this.displayName);
    }
}
